textmining.TsujiiC3.SimpleTokenizer

|  | ## Cheshire3 Object Model: Class SimpleTokenizer

Package textmining :: Module TsujiiC3 :: Class SimpleTokenizer

## Class SimpleTokenizer
source code

Instance Methods

__init__(self)
split_paragraphs(self, data)
split_sentences(self, data)

Method Details

### __init__(self) (Constructor) | source code

### split_paragraphs(self, data) | source code

### split_sentences(self, data) | source code